===============================
pyrise
===============================

.. image:: https://badges.gitter.im/pyrise/Lobby.svg
   :alt: Join the chat at https://gitter.im/pyrise/Lobby
   :target: https://gitter.im/pyrise/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge


.. image:: https://img.shields.io/pypi/v/pyrise.svg
        :target: https://pypi.python.org/pypi/pyrise

.. image:: https://img.shields.io/travis/michaelaye/pyrise.svg
        :target: https://travis-ci.org/michaelaye/pyrise

.. image:: https://readthedocs.org/projects/hirise-tools/badge/?version=latest
        :target: https://hirise-tools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/michaelaye/pyrise/shield.svg
     :target: https://pyup.io/repos/github/michaelaye/pyrise/
     :alt: Updates


* Free software: ISC license
* Documentation: https://hirise-tools.readthedocs.io.


Features
--------

* the `products` module offers full standard path creations for all HiRISE products.
* the `downloads` module offers helpers to download HiRISE full and browse products
* for Mac only, a command-line tool called 'abrowse' is installed that downloads and opens annotated browse products in the Preview.app

Credits
---------

This package was created with Cookiecutter_ and the forked `michaelaye/cookiecutter-pypackage-conda`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`michaelaye/cookiecutter-pypackage-conda`: https://github.com/michaelaye/cookiecutter-pypackage-conda
